@@ -1,4 +1,4 @@
-# $Revision: #38 $$Date: 2004/07/22 $$Author: ws150726 $
+# $Revision: #41 $$Date: 2004/10/26 $$Author: ws150726 $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -20,7 +20,7 @@ use Bit::Vector::Overload;
 use strict;
 use vars qw (@ISA $VERSION);
 @ISA = qw (SystemC::Vregs::Subclass);
-$VERSION = '1.245';
+$VERSION = '1.246';
 
 #Fields:
 #	{name}			Field name (Subclass)
@@ -492,12 +492,20 @@ Checks the object for errors, and parses to create derived Fields.
 
 =back
 
-=head1 SEE ALSO
+=head1 DISTRIBUTION
 
-C<SystemC::Vregs>
+The latest version is available from CPAN and from L<http://www.veripool.com/>.
+
+Copyright 2001-2004 by Wilson Snyder.  This package is free software; you
+can redistribute it and/or modify it under the terms of either the GNU
+Lesser General Public License or the Perl Artistic License.
 
 =head1 AUTHORS
 
 Wilson Snyder <wsnyder@wsnyder.org>
 
+=head1 SEE ALSO
+
+L<SystemC::Vregs>
+
 =cut
