@@ -1,4 +1,4 @@
-# $Revision: #17 $$Date: 2004/07/22 $$Author: ws150726 $
+# $Revision: #20 $$Date: 2004/10/26 $$Author: ws150726 $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -21,7 +21,7 @@ use vars qw($VERSION @ISA);
 use Bit::Vector;
 
 @ISA = qw (Bit::Vector);	# For now, let Bit::Vector do all the work
-$VERSION = '1.245';
+$VERSION = '1.246';
 
 ######################################################################
 ######################################################################
@@ -97,12 +97,20 @@ SystemC::Vregs::Number - Number parsing used by Vregs
 This package is used to extract numbers in C++ or Verilog format into a
 Bit::Vector.
 
-=head1 SEE ALSO
+=head1 DISTRIBUTION
 
-C<SystemC::Vregs>
+The latest version is available from CPAN and from L<http://www.veripool.com/>.
+
+Copyright 2001-2004 by Wilson Snyder.  This package is free software; you
+can redistribute it and/or modify it under the terms of either the GNU
+Lesser General Public License or the Perl Artistic License.
 
 =head1 AUTHORS
 
 Wilson Snyder <wsnyder@wsnyder.org>
 
+=head1 SEE ALSO
+
+L<SystemC::Vregs>
+
 =cut
