@@ -1,4 +1,4 @@
-# $Revision: #14 $$Date: 2004/07/22 $$Author: ws150726 $
+# $Revision: #17 $$Date: 2004/10/26 $$Author: ws150726 $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -17,7 +17,7 @@ package SystemC::Vregs::OutputNamed;
 use File::Basename;
 use Carp;
 use vars qw($VERSION);
-$VERSION = '1.245';
+$VERSION = '1.246';
 
 use SystemC::Vregs::Outputs;
 use SystemC::Vregs::Number;
@@ -137,12 +137,20 @@ to appropriate pointer types for dumping to a stream.
 
 =back
 
-=head1 SEE ALSO
+=head1 DISTRIBUTION
 
-C<SystemC::Vregs::Output>
+The latest version is available from CPAN and from L<http://www.veripool.com/>.
+
+Copyright 2001-2004 by Wilson Snyder.  This package is free software; you
+can redistribute it and/or modify it under the terms of either the GNU
+Lesser General Public License or the Perl Artistic License.
 
 =head1 AUTHORS
 
 Wilson Snyder <wsnyder@wsnyder.org>
 
+=head1 SEE ALSO
+
+L<SystemC::Vregs::Output>
+
 =cut
